#if defined _shvector_included
  #endinput
#endif
#define _shvector_included

#include <core>

#define TYPE_CELL 0
#define TYPE_STRING 1
#define ITER_FRONT 0
#define ITER_BACK 1

/**
 * Creates a SHVector
 * @param type      The type of vector to create (TYPE_CELL or TYPE_STRING)
 * @return          The SHVector handle of the result
 */
native Handle:SHVectorCreate(type=TYPE_CELL);

/**
 * Frees the vector from the memory
 * @param vector    The vector to free from the memory
 * @noreturn
 */
native SHVectorFree_Cell(Handle:vector);
native SHVectorFree_String(Handle:vector);

/**
 * Gets the vector value at the provided position
 * @param vector    The vector to use
 * @param pos       The position in the vector to get the value of
 * @return          The value
 */
native any:SHVectorAt_Cell(Handle:vector,pos);
native SHVectorAt_String(Handle:vector,pos,String:storeto[],maxlen);

/**
 * Sets the vector value at the provided position
 * @param vector    The vector to use
 * @param pos       The position in the vector to set the value of
 * @param value     The value to set as
 * @return          Returns 0 if there was a failure 
 */
native SHVectorSetAt_Cell(Handle:vector,pos,any:value);
native SHVectorSetAt_String(Handle:vector,pos,String:value[]);

/**
 * Clear the whole vector provided
 * @param vector    The vector to use
 * @noreturn 
 */
native SHVectorClear_Cell(Handle:vector);
native SHVectorClear_String(Handle:vector);

/**
 * Is the vector empty?
 * @param vector    The vector to use
 * @return          Returns true if the vector is empty
 */
native bool:SHVectorIsEmpty_Cell(Handle:vector);
native bool:SHVectorIsEmpty_String(Handle:vector);

/**
 * Swap the contents of two pos's in a vector
 * @param vector  The Vector to use
 * @param pos1    One of the pos's
 * @param pos2    The other pos  
 * @return        Returns 0 if there was a failure
 */
native SHVectorSwap_Cell(Handle:vector,pos1,pos2);
native SHVectorSwap_String(Handle:vector,pos1,pos2);

/**
 * Insert a new item into a vector
 * @param vector    The vector to use
 * @param where     Where to put the item (ITER_FRONT or ITER_BACK) 
 * @param value     The value to insert 
 * @return          Returns 0 if there was a failure
 */
native SHVectorInsert_Cell(Handle:vector,where,any:value);
native SHVectorInsert_String(Handle:vector,where,String:value[]);

/**
 * Erase an item from the vector
 * @param vector    The vector to use
 * @param pos       The position to delete from the vector
 * @return          Returns 0 if there was a failure
 */
native SHVectorErase_Cell(Handle:vector,pos);
native SHVectorErase_String(Handle:vector,pos);

/**
 * The amount of items in the vector
 * @param vector    The vector to use
 * @return          Returns the amount of items in the vector
 */
native SHVectorSize_Cell(Handle:vector);
native SHVectorSize_String(Handle:vector);

/**
 * @endsection
 */

/**
 * Do not edit below this line!
 */
public Extension:__ext_shvector = 
{
	name = "SHVector Extension",
	file = "shvector.ext",
#if defined AUTOLOAD_EXTENSIONS
	autoload = 1,
#else
	autoload = 0,
#endif
#if defined REQUIRE_EXTENSIONS
	required = 1,
#else
	required = 0,
#endif
};
